pub trait SocketWritableListener {
// Required method
fn on_writable_changed(&mut self, writable: bool);
}Expand description
A type capable of handling socket writable changes.
Upon creation, listeners must always assume the socket is writable.
Required Methods
Sourcefn on_writable_changed(&mut self, writable: bool)
fn on_writable_changed(&mut self, writable: bool)
Notifies the listener the writable state has changed to writable.
Callers must only call this when the writable state has actually changed. Implementers may panic if they see the current state being notified as changed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".