NeverBuffer

Struct NeverBuffer 

pub struct NeverBuffer(/* private fields */);
A buffer that is never used.

Note that this is needed because of the [AsMut<[u8]>] bound required. It is not possible work around this with a local trait. That approach requires a blanket impl which the compiler will complain that the core crate can eventually add a impl for the Infallible type. When that happens, we can remove this local type.