pub struct FakeCryptoRng<R = XorShiftRng>(/* private fields */);Expand description
A wrapper which implements Rng and CryptoRng for any Rng.
This is used to satisfy RngContext’s requirement that the
associated Rng type implements CryptoRng.
Security
This is obviously insecure. Don’t use it except in testing!
Implementations
Sourceimpl FakeCryptoRng<XorShiftRng>
impl FakeCryptoRng<XorShiftRng>
Sourcepub fn new_xorshift(seed: u128) -> FakeCryptoRng<XorShiftRng>
pub fn new_xorshift(seed: u128) -> FakeCryptoRng<XorShiftRng>
Creates a new FakeCryptoRng<XorShiftRng> from a seed.
Sourcepub fn deep_clone(&self) -> Self
pub fn deep_clone(&self) -> Self
Returns a deep clone of this RNG, copying the current RNG state.
Sourcepub fn with_fake_rngs<F: Fn(Self)>(iterations: u128, f: F)
pub fn with_fake_rngs<F: Fn(Self)>(iterations: u128, f: F)
Creates iterations fake RNGs.
with_fake_rngs will create iterations different
FakeCryptoRngs and call the function f for each one of them.
This function can be used for tests that weed out weirdness that can happen with certain random number sequences.