pub trait AlwaysDefaultsSettingsContext { }Expand description
A marker trait that allows a type to implement SettingsContext that
always yields a default value for the settings type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".