Bencher

Trait Bencher 

pub trait Bencher {
    // Required methods
    fn iter<T, F: FnMut() -> T>(&mut self, inner: F);
    fn black_box<T>(placeholder: T) -> T;
}
A trait to allow faking of the type providing benchmarking.

Required Methods

fn iter<T, F: FnMut() -> T>(&mut self, inner: F)

Benchmarks inner by running it multiple times.

fn black_box<T>(placeholder: T) -> T

Abstracts blackboxing.

black_box prevents the compiler from optimizing a function with an unused return type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors