WithFakeFrameContext

Trait WithFakeFrameContext 

pub trait WithFakeFrameContext<SendMeta> {
    // Required method
    fn with_fake_frame_ctx_mut<O, F: FnOnce(&mut FakeFrameCtx<SendMeta>) -> O>(
        &mut self,
        f: F,
    ) -> O;
}
A trait for abstracting contexts that may contain a FakeFrameCtx.

Required Methods

fn with_fake_frame_ctx_mut<O, F: FnOnce(&mut FakeFrameCtx<SendMeta>) -> O>( &mut self, f: F, ) -> O

Calls the callback with a mutable reference to the FakeFrameCtx.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S, Meta, DeviceId> WithFakeFrameContext<Meta> for FakeCoreCtx<S, Meta, DeviceId>

Source

impl<SendMeta> WithFakeFrameContext<SendMeta> for FakeFrameCtx<SendMeta>