pub trait Device: 'static { }Expand description
A device.
Device is used to identify a particular device implementation. It
is only intended to exist at the type level, never instantiated at runtime.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".