pub trait EventContext<T> {
// Required method
fn on_event(&mut self, event: T);
}Expand description
A context for emitting events.
EventContext encodes the common pattern for emitting atomic events of type
T from core. An implementation of EventContext must guarantee that
events are processed in the order they are emitted.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".