pub trait HandleableTimer<CC, BC: TimerBindingsTypes> {
// Required method
fn handle(
self,
core_ctx: &mut CC,
bindings_ctx: &mut BC,
timer: BC::UniqueTimerId,
);
}Expand description
A timer that can be handled by a pair of core context CC and bindings
context BC.
This trait exists to sidestep coherence issues when dealing with timer
layers, see TimerHandler for more.
Required Methods
Sourcefn handle(
self,
core_ctx: &mut CC,
bindings_ctx: &mut BC,
timer: BC::UniqueTimerId,
)
fn handle( self, core_ctx: &mut CC, bindings_ctx: &mut BC, timer: BC::UniqueTimerId, )
Handles this timer firing.
timer is the unique timer identifier for the
TimerBindingsTypes::Timer that scheduled this operation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".