SettingsContext

Trait SettingsContext 

pub trait SettingsContext<T> {
    // Required method
    fn settings(&self) -> impl Deref<Target = T> + '_;
}
Abstracts access to stack settings.

This trait is implemented by bindings to allow core access to runtime-configurable behavior for the network stack.

Separate modules declare their own T for settings structures that can be retrieved via this trait.

Required Methods

fn settings(&self) -> impl Deref<Target = T> + '_

Borrows the current settings values.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, O> SettingsContext<T> for O
where T: Default + 'static, O: AlwaysDefaultsSettingsContext,