pub trait LinkDevice: Device + Debug {
type Address: LinkDeviceAddress;
}Expand description
A link device.
LinkDevice is used to identify a particular link device implementation. It
is only intended to exist at the type level, never instantiated at runtime.
Required Associated Types
Sourcetype Address: LinkDeviceAddress
type Address: LinkDeviceAddress
The type of address used to address link devices of this type.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".