pub trait ResourceCounterContext<R, T>: CounterContext<T> {
// Required method
fn per_resource_counters<'a>(&'a self, resource: &'a R) -> &'a T;
// Provided methods
fn increment_both<F: Fn(&T) -> &Counter>(&self, resource: &R, cb: F) { ... }
fn add_both<F: Fn(&T) -> &Counter>(&self, resource: &R, value: u64, cb: F) { ... }
fn add_both_usize<F: Fn(&T) -> &Counter>(
&self,
resource: &R,
value: usize,
cb: F,
) { ... }
}Expand description
A context that provides access to per-resource counters for observation and debugging.
Required Methods
Sourcefn per_resource_counters<'a>(&'a self, resource: &'a R) -> &'a T
fn per_resource_counters<'a>(&'a self, resource: &'a R) -> &'a T
Returns a reference to the set of counters on resource.
Provided Methods
Sourcefn increment_both<F: Fn(&T) -> &Counter>(&self, resource: &R, cb: F)
fn increment_both<F: Fn(&T) -> &Counter>(&self, resource: &R, cb: F)
Increments both the per-resource and stackwide versions of the counter returned by the callback.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".