pub type LocalFrameDestination = FrameDestination<()>;Expand description
A FrameDestination that is guaranteed to be destined to this host if it is
an individual address.
Aliased Type
pub enum LocalFrameDestination {
Individual {
local: (),
},
Multicast,
Broadcast,
}Variants
Individual
A unicast address - one which is neither multicast nor broadcast.
Multicast
A multicast address; if the addressing scheme supports overlap between
multicast and broadcast, then broadcast addresses should use the
Broadcast variant.
Broadcast
A broadcast address; if the addressing scheme supports overlap between
multicast and broadcast, then broadcast addresses should use the
Broadcast variant.